import eHive
import os

from VCF.VCFIntegration.Shapeit import Shapeit

class run_ligateHAPLOTYPES(eHive.BaseRunnable):
    """
    Run ligateHAPLOTYPES on the different chunks generated by SHAPEIT
    in order to produce a single output file
    """

    def run(self):

        verbose = None
        if self.param_is_defined('verbose'):
            verbose = True
        else:
            verbose = False

        if not os.path.isdir(self.param_required('work_dir')):
            os.makedirs(self.param_required('work_dir'))

        # process the file paths in order to shorten the cmd line
        cwd = os.getcwd()
        basenames = [os.path.basename(x) for x in self.param_required('hapgz_list')]
        chunk_str = " ".join(basenames)
        os.chdir(self.param_required('work_dir')+"/shapeit")

        outprefix = os.path.split(self.param_required('outprefix'))[1]
        outprefix = "{0}/{1}".format(self.param_required('work_dir'), outprefix)

        shapeit_object = Shapeit(ligateHAPLOTYPES_folder=
                                 self.param_required('ligateHAPLOTYPES_folder'))

        outdict = shapeit_object.ligate_shapeitchunks(vcf_f=self.param_required('vcf_f'),
                                                      scaffolded_samples=
                                                      self.param_required('scaffolded_samples'),
                                                      chunk_str=chunk_str,
                                                      output_prefix=outprefix,
                                                      verbose=verbose)
        #go back to current work dir
        os.chdir(cwd)

        self.param('outdict', outdict)

    def write_output(self):
        self.warning('Work is done!')

        outdict = self.param('outdict')
        self.dataflow({
            'hap_gz': outdict['hap_gz'],
            'hap_sample': outdict['hap_sample']
        }, 1)
